==> ulyxex.0.0.4.with-tinyMce.zip: pages/code/view_page.php <==
<?php
class ViewPage extends Ulyxex {
	public function totalItems($catId) {
		$req = "SELECT COUNT(ID) AS NUM FROM ".ARTICLES." WHERE PAGEID = ".$catId." AND HIDE != 1";
		$req = $this->req($req);
		$result = mysql_fetch_assoc($req);
		return $result['NUM'];	
	}
	public function page_exist($catId) {
		$req = "SELECT ID FROM ".PAGES." WHERE ID = ".$catId;
		$req = $this->req($req);
		$result = @mysql_fetch_assoc($req);
		return $result['ID'];	
	}
	public function page_hide($catId) {
		$req = "SELECT HIDE FROM ".PAGES." WHERE ID = ".$catId;
		$req = $this->req($req);
		$dat = @mysql_fetch_assoc($req);
		return $dat['HIDE'];
	}
	public function page_data($catId,$pgPos=0) {
		$h = New Html();
		if ($pgPos) $pgPos = ($pgPos - 1) * ARTICLESBYPAGE;
		if ($this->page_hide($catId) == 1 || $this->page_exist($catId) == null) {
			return $h->h3("no page !");
		} else {
			$req = "SELECT ".ARTICLES.".*,".USERS.".USERNAME FROM ".ARTICLES.",".USERS.
						" WHERE ".ARTICLES.".PAGEID=".$catId." AND ".
						ARTICLES.".HIDE = 0 AND ".
						USERS.".ID = ".ARTICLES.".USERID".
						" ORDER BY DATE DESC".
						" LIMIT ".$pgPos.",".ARTICLESBYPAGE;
						
			$req = $this->req($req);
			$result = "";
			while ( $line = mysql_fetch_assoc($req) ) {
				$result .= $h->div($line['CONTENT']);
				$result .= $h->p($h->ahref("index.php?user=".$line['USERID'],$line['USERNAME'])." ".$line['DATE']." ".$h->ahref("index.php?art=".$line['ID'],"url"));
			}
			return $result;
		}
	}
	
}
class NextPages extends ViewPage {
	public function __construct($catId) {
		$this->items = $this->totalItems($catId);
		$this->catId = $catId;
		$h = new Html();
		$this->pagePos = isset($_GET['pg'])?$h->num($_GET['pg']):0;
	}
	public function numbers() {
		$h = new Html();
		/* total pages */
		$pages = $this->items/ARTICLESBYPAGE; 
		$pages++;
		$result = "";
		if ($pages > 2) {
			for($i=1;$i < $pages;$i++) {
				$num = $i?strval($i):"0";
				if ($i == $this->pagePos) {
					$result .= "(".$h->ahref("index.php?cat=".$this->catId."&amp;pg=".$num,$num).") ";
				} else {
					$result .= $h->ahref("index.php?cat=".$this->catId."&amp;pg=".$num,$num)." ";
				}
			}
		}
		return $result;
	}
}
?>

==> ulyxex.0.0.5.with-tinyMce.zip: pages/code/view_page.php <==
<?php
class ViewPage extends Ulyxex {
	public function totalItems($catId) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".ARTICLES." WHERE PAGEID = ".$catId." AND HIDE != 1";
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function page_exist($catId) {
		$query = "SELECT ID FROM ".PAGES." WHERE ID = ".$catId;
		$query = $this->q($query);
		$result = @mysql_fetch_assoc($query);
		return $result['ID'];	
	}
	public function page_hide($catId) {
		$query = "SELECT HIDE FROM ".PAGES." WHERE ID = ".$catId;
		$query = $this->q($query);
		$dat = @mysql_fetch_assoc($query);
		return $dat['HIDE'];
	}
	public function page_data($catId,$pgPos=0) {
		$h = New Html();
		if ($pgPos) $pgPos = ($pgPos - 1) * ARTICLESBYPAGE;
		if ($this->page_hide($catId) == 1 || $this->page_exist($catId) == null) {
			return $h->h3("no page !");
		} else {
			$query = "SELECT ".ARTICLES.".*,".USERS.".USERNAME FROM ".ARTICLES.",".USERS.
						" WHERE ".ARTICLES.".PAGEID=".$catId." AND ".
						ARTICLES.".HIDE = 0 AND ".
						USERS.".ID = ".ARTICLES.".USERID".
						" ORDER BY DATE DESC".
						" LIMIT ".$pgPos.",".ARTICLESBYPAGE;
						
			$query = $this->q($query);
			$result = "";
			while ( $line = mysql_fetch_assoc($query) ) {
				$result .= $h->div($line['CONTENT']);
				$result .= $h->p($h->ahref("index.php?user=".$line['USERID'],$line['USERNAME'])." ".$line['DATE']." ".$h->ahref("index.php?art=".$line['ID'],"url"));
			}
			return $result;
		}
	}
	
}
class NextPages extends ViewPage {
	public function __construct($catId) {
		$this->items = $this->totalItems($catId);
		$this->catId = $catId;
		$h = new Html();
		$this->pagePos = isset($_GET['pg'])?$h->num($_GET['pg']):0;
	}
	public function numbers() {
		$h = new Html();
		/* total pages */
		$pages = $this->items/ARTICLESBYPAGE; 
		$pages++;
		$result = "";
		if ($pages > 2) {
			for($i=1;$i < $pages;$i++) {
				$num = $i?strval($i):"0";
				if ($i == $this->pagePos) {
					$result .= "(".$h->ahref("index.php?cat=".$this->catId."&amp;pg=".$num,$num).") ";
				} else {
					$result .= $h->ahref("index.php?cat=".$this->catId."&amp;pg=".$num,$num)." ";
				}
			}
		}
		return $result;
	}
}
?>
